@@ -1,43 +1,51 @@
+#' Hexagon bining.
+#'
+#' @section Aesthetics:
+#' \Sexpr[results=rd,stage=build]{ggplot2:::rd_aesthetics("geom", "hex")}
+#'
+#' @export
+#' @inheritParams geom_point
+#' @examples
+#' # See ?stat_binhex for examples
+geom_hex <- function (mapping = NULL, data = NULL, stat = "binhex", position = "identity", ...) {
+  GeomHex$new(mapping = mapping, data = data, stat = stat, position = position, ...)
+}
+
 GeomHex <- proto(Geom, {
   objname <- "hex"
-  desc <- "Tile the plane with hexagons"
 
-  draw <- function(., data, scales, coordinates, ...) { 
-    with(coordinates$transform(data, scales), 
-      ggname(.$my_name(), hexGrob(x, y, col=colour, 
+  draw <- function(., data, scales, coordinates, ...) {
+    with(coord_transform(coordinates, data, scales),
+      ggname(.$my_name(), hexGrob(x, y, col=colour,
         fill = alpha(fill, alpha)))
     )
   }
-  
+
   required_aes <- c("x", "y")
-  default_aes <- function(.) aes(colour=NA, fill = "grey50", size=0.5, alpha = 1)
+  default_aes <- function(.) aes(colour=NA, fill = "grey50", size=0.5, alpha = NA)
   default_stat <- function(.) StatBinhex
   guide_geom <- function(.) "polygon"
-  
-  examples <- function() {
-    # See ?stat_binhex for examples  
-  }
-  
+
 })
 
 
 # Draw hexagon grob
 # Modified from code by Nicholas Lewin-Koh and Martin Maechler
-# 
-# @arguments x positions of hex centres
-# @arguments y positions
-# @arguments vector of hex sizes
-# @arguments border colour
-# @arguments fill colour
+#
+# @param x positions of hex centres
+# @param y positions
+# @param vector of hex sizes
+# @param border colour
+# @param fill colour
 # @keyword internal
 hexGrob <- function(x, y, size = rep(1, length(x)), colour = "grey50", fill = "grey90") {
   stopifnot(length(y) == length(x))
-  
+
   dx <- resolution(x, FALSE)
   dy <- resolution(y, FALSE) / sqrt(3) / 2 * 1.15
-  
+
   hexC <- hexcoords(dx, dy, n = 1)
-  
+
   n <- length(x)
 
   polygonGrob(
@@ -46,4 +54,4 @@ hexGrob <- function(x, y, size = rep(1, length(x)), colour = "grey50", fill = "g
     default.units = "native",
     id.lengths = rep(6, n), gp = gpar(col = colour, fill = fill)
   )
-}
\ No newline at end of file
+}
