@@ -1,7 +1,8 @@
 # Scales object encapsultes multiple scales.
-# All input and output done with data.frames to facilitate 
+# All input and output done with data.frames to facilitate
 # multiple input and output variables
 
+#' @importFrom methods setRefClass
 Scales <- setRefClass("Scales", fields = "scales", methods = list(
   find = function(aesthetic) {
     vapply(scales, function(x) any(aesthetic %in% x$aesthetics), logical(1))
@@ -22,7 +23,7 @@ Scales <- setRefClass("Scales", fields = "scales", methods = list(
 
     # Remove old scale for this aesthetic (if it exists)
     scales <<- c(scales[!prev_aes], list(scale))
-  }, 
+  },
   clone = function() {
     new_scales <- lapply(scales, scale_clone)
     Scales$new(new_scales)
@@ -32,7 +33,7 @@ Scales <- setRefClass("Scales", fields = "scales", methods = list(
   },
   input = function() {
     unlist(lapply(scales, "[[", "aesthetics"))
-  }, 
+  },
   initialize = function(scales = NULL) {
     initFields(scales = scales)
   },
@@ -43,7 +44,7 @@ Scales <- setRefClass("Scales", fields = "scales", methods = list(
     scale <- scales[find(output)]
     if (length(scale) == 0) return()
     scale[[1]]
-  }  
+  }
 ))
 
 # Train scale from a data frame
@@ -55,17 +56,17 @@ scales_train_df <- function(scales, df, drop = FALSE) {
 
 # Map values from a data.frame. Returns data.frame
 scales_map_df <- function(scales, df) {
-  if (empty(df) || length(scales$scales) == 0) return()
-  
+  if (empty(df) || length(scales$scales) == 0) return(df)
+
   mapped <- unlist(lapply(scales$scales, scale_map_df, df = df), recursive = FALSE)
-  
+
   quickdf(c(mapped, df[setdiff(names(df), names(mapped))]))
 }
 
 # Transform values to cardinal representation
 scales_transform_df <- function(scales, df) {
   if (empty(df) || length(scales$scales) == 0) return(df)
-  
+
   transformed <- unlist(lapply(scales$scales, scale_transform_df, df = df),
     recursive = FALSE)
   quickdf(c(transformed, df[setdiff(names(df), names(transformed))]))
@@ -76,13 +77,13 @@ scales_transform_df <- function(scales, df) {
 scales_add_defaults <- function(scales, data, aesthetics, env) {
   if (is.null(aesthetics)) return()
   names(aesthetics) <- unlist(lapply(names(aesthetics), aes_to_scale))
-  
+
   new_aesthetics <- setdiff(names(aesthetics), scales$input())
   # No new aesthetics, so no new scales to add
   if (is.null(new_aesthetics)) return()
-  
+
   datacols <- tryapply(
-    aesthetics[new_aesthetics], eval, 
+    aesthetics[new_aesthetics], eval,
     envir = data, enclos = env
   )
 
@@ -91,12 +92,12 @@ scales_add_defaults <- function(scales, data, aesthetics, env) {
     scale_name <- paste("scale", aes, type, sep="_")
 
     # Skip aesthetics with no scales (e.g. group, order, etc)
-    scale_f <- find_global(scale_name, env)
+    scale_f <- find_global(scale_name, env, mode = "function")
     if (is.null(scale_f)) next
 
     scales$add(scale_f())
   }
-  
+
 }
 
 # Add missing but required scales.
@@ -109,25 +110,25 @@ scales_add_missing <- function(plot, aesthetics, env) {
   for (aes in aesthetics) {
     scale_name <- paste("scale", aes, "continuous", sep="_")
 
-    scale_f <- find_global(scale_name, env)
+    scale_f <- find_global(scale_name, env, mode = "function")
     plot$scales$add(scale_f())
   }
 }
 
 
-# Look for object first in parent environment and if not found, then in 
+# Look for object first in parent environment and if not found, then in
 # ggplot2 namespace environment.  This makes it possible to override default
 # scales by setting them in the parent environment.
-find_global <- function(name, env) {
-  if (exists(name, env)) {
-    return(get(name, env))
+find_global <- function(name, env, mode = "any") {
+  if (exists(name, envir = env, mode = mode)) {
+    return(get(name, envir = env, mode = mode))
   }
 
   nsenv <- asNamespace("ggplot2")
-  if (exists(name, nsenv)) {
-    return(get(name, nsenv))
+  if (exists(name, envir = nsenv, mode = mode)) {
+    return(get(name, envir = nsenv, mode = mode))
   }
-  
+
   NULL
 }
 
@@ -135,27 +136,27 @@ find_global <- function(name, env) {
 # Determine default type of a scale
 scale_type <- function(x) UseMethod("scale_type")
 
-#' @S3method scale_type default
+#' @export
 scale_type.default <- function(x) {
   message("Don't know how to automatically pick scale for object of type ",
     paste(class(x), collapse = "/"), ". Defaulting to continuous")
   "continuous"
 }
 
-#' @S3method scale_type logical
+#' @export
 scale_type.logical <- function(x) "discrete"
 
-#' @S3method scale_type character
+#' @export
 scale_type.character <- function(x) "discrete"
 
-#' @S3method scale_type factor
+#' @export
 scale_type.factor <- function(x) "discrete"
 
-#' @S3method scale_type POSIXt
+#' @export
 scale_type.POSIXt <- function(x) "datetime"
 
-#' @S3method scale_type Date
+#' @export
 scale_type.Date <- function(x) "date"
 
-#' @S3method scale_type numeric
+#' @export
 scale_type.numeric <- function(x) "continuous"
